"""Built-in datasets for demonstration, educational and test purposes.
"""

from plotly.data import *

__all__ = [
    "carshare",
    "election",
    "election_geojson",
    "experiment",
    "gapminder",
    "iris",
    "medals_wide",
    "medals_long",
    "stocks",
    "tips",
    "wind",
]
